"""
Tests?  We don't need no stinkin' tests!

Pull requests welcome ;)

Here's the problem with tests.  Life's too short to write them.  My approach to
testing is the following:
1) Run the program.
2) If it breaks, fix it.

How many times have you come across a package where the tests folder contains
more code than the actual project?  Is this really a good way of spending your
precious coding time?  I know this philosophy is not going to win me much
support, and it's quite a dangerous and childish and wholly unprofessional way
of developing software.  Maybe I'll fix this in the future, but for now I really
really don't have time to write tests for this package and I'm not going to
stress about it, no matter how much grief I get for it.

"""
